function  scores = sirene_predict_libsvm(sireneData)
%
% scores = sirene_predict(sireneData)
%
% Predict new edges with SIRENE using libsvm
%
% REQUIRED:
%  - libsvm should be on the path
%
% INPUTS:
%  - sireneData : a structure containing the features, the edges and
%  various parameters, as initialized by sirene_initialize()
% 
% OUTPUT:
%  a (N-k) X s matrix of scores corresponding to the edges starting from the s
%  source vertices to the N-k vertices of sireneData.toPredict

%%

% Matrix of known edges starting from vertices in the sourcevertices list
% (one column for each source vertex)
[~, ~, indSource]=unique(sireneData.edge(:,1));
Cgold = -ones(sireneData.nvertex,sireneData.nsource);
for i=1:sireneData.nedge
    Cgold(sireneData.edge(i,2),indSource(i)) = 1;
end

% prediction loop
scores = zeros(length(sireneData.toPredict),sireneData.nsource);
alltrain = sireneData.knownTargets;
alltest = sireneData.toPredict;

for isource=1:sireneData.nsource

    trainlabels = Cgold(sireneData.knownTargets,isource);
    testlabels = Cgold(sireneData.toPredict,isource);

    npos = sum(trainlabels>0.5);

    if npos == 0
        scores(:,isource) = -1;
    else

        gamma = 1/(2*sireneData.param*sireneData.param);
        model = svmtrain(trainlabels,sireneData.feature(alltrain,:),strcat(['-t 2 -g ',num2str(gamma),' -c ',num2str(sireneData.C)]));

        % Make the prediction on test data
        [p,a,v] = svmpredict(testlabels,sireneData.feature(alltest,:),model);

        % Warning, the decision function of libsvm considers the first
        % label as the positive class...
        scores(:,isource) = v*(trainlabels(1));
    end

end



